[prev in list] [next in list] [prev in thread] [next in thread] 

List:       kde-commits
Subject:    [kde-workspace/KDE/4.9] plasma/generic/applets/notifications/core: auto-deletion only triggered by m
From:       Martin Koller <kollix () aon ! at>
Date:       2012-08-06 16:51:17
Message-ID: 20120806165117.8FAEFA6094 () git ! kde ! org
[Download RAW message or body]

Git commit f707362a2f6c1c980983341e1cee3d96848e470e by Martin Koller.
Committed on 06/08/2012 at 18:43.
Pushed by mkoller into branch 'KDE/4.9'.

auto-deletion only triggered by manager

the auto-deletion timer shall only be started from one single place, which is
the notificationmanager, which starts the timer only if there is user activity on the \
desktop so that a notification which arrives while the user is not at his desk does \
not get deleted unseen. We agreed on reducing the timeout to 10 minutes

REVIEW: 105893

M  +5    -4    plasma/generic/applets/notifications/core/notification.cpp

http://commits.kde.org/kde-workspace/f707362a2f6c1c980983341e1cee3d96848e470e

diff --git a/plasma/generic/applets/notifications/core/notification.cpp \
b/plasma/generic/applets/notifications/core/notification.cpp index 1e1350e..26833b6 \
                100644
--- a/plasma/generic/applets/notifications/core/notification.cpp
+++ b/plasma/generic/applets/notifications/core/notification.cpp
@@ -167,11 +167,12 @@ void Notification::setUrgency(int urgency)
     if (urgency != d->urgency) {
         d->urgency = urgency;
         if (urgency >= 2) {
-            d->hideTimer->stop();
+            if (d->hideTimer) {
+                d->hideTimer->stop();
+            }
             d->deleteTimer->stop();
         } else {
             setTimeout(d->timeout);
-            startDeletionCountdown();
         }
     }
 }
@@ -235,8 +236,8 @@ void Notification::startDeletionCountdown()
         return;
     }
 
-    //keep it available for 20 minutes
-    d->deleteTimer->start(20*60*1000);
+    //keep it available for 10 minutes
+    d->deleteTimer->start(10*60*1000);
 }
 
 bool Notification::isExpired() const


[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic